@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2014 Zagaran, Inc.
+Copyright (c) 2015 Zagaran, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -29,5 +29,6 @@ class TemplateDatabaseError(Exception): pass
 class DatabaseConflictError(Exception): pass
 class RequiredKeyError(Exception): pass
 class InvalidKeyError(Exception): pass
+class InvalidTypeError(Exception): pass
 class DatabaseIsDownError(Exception): pass
-
+class NonexistentObjectError(Exception): pass
